==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/hu.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Magas kontrasztú téma",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "A magas kontrasztú téma megkönnyíti a navigációt. A képi minőség csökken, de az olvashatóság javul.",
    "Dark theme (beta)" : "Sötét téma (béta)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "A sötét téma csökkenti a szemek terhelését az átlagos fényesség és fényerő csökkentésével. Még mindig fejlesztés alatt áll, így jelentse ha problémát talál.",
    "Dyslexia font" : "Diszlexia betűkészlet",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Az OpenDyslexic egy szabad betűkészlet, amely egyes, diszlexia által okozott, gyakori olvasási hibák csökkentésére lett tervezve.",
    "Accessibility" : "Akadálymentesítés",
    "Accessibility options for nextcloud" : "Akadálymentesítési lehetőségek a Nextcloudhoz",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Több akadálymentesítési lehetőséget biztosít, hogy megkönnyítse a Nextcloud használatát",
    "Web Content Accessibility Guidelines" : "Webes tartalom akadálymentesítési irányelvek",
    "our issue tracker" : "a hibakövetőnk",
    "our design team" : "a fejlesztőcsapatunk",
    "Enable" : "Engedélyezés"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/hu.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Magas kontrasztú téma",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "A magas kontrasztú téma megkönnyíti a navigációt. A képi minőség csökken, de az olvashatóság javul.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "A sötét téma csökkenti a szemek terhelését az átlagos fényesség és fényerő csökkentésével. Még mindig fejlesztés alatt áll, így jelentse ha problémát talál.",
    "Dyslexia font" : "Diszlexia betűkészlet",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Az OpenDyslexic egy szabad betűkészlet, amely egyes, diszlexia által okozott, gyakori olvasási hibák csökkentésére lett tervezve.",
    "Accessibility" : "Akadálymentesítés",
    "Accessibility options for nextcloud" : "Akadálymentesítési lehetőségek a Nextcloudhoz",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Több akadálymentesítési lehetőséget biztosít, hogy megkönnyítse a Nextcloud használatát",
    "Web Content Accessibility Guidelines" : "Webes tartalom akadálymentesítési irányelvek",
    "our issue tracker" : "a hibakövetőnk",
    "our design team" : "a fejlesztőcsapatunk",
    "Enable" : "Engedélyezés",
    "Dark theme (beta)" : "Sötét téma (béta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "Az OpenDyslexic egy szabad betűkészlet, amely egyes, diszlexia által okozott, gyakori olvasási hibák csökkentésére lett tervezve. A betűkészletet Abelardo Gonzalez tervezte, aki nyílt forráskódú licenc alatt adta közre.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Több akadálymentesítési lehetőséget biztosít, hogy megkönnyítse a Nextcloud használatát",
    "Themes" : "Témák",
    "Fonts" : "Betűkészletek",
    "enabled" : "engedélyezett"
},
"nplurals=2; plural=(n != 1);");
